﻿using _123.Domain.UseCase;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace _123.UI
{
    public class PresenceConsoleUI
    {
        PresenceUseCase _presenceUseCase;
        UseCaseGeneratePresence _useCaseGeneratePresence;

        public PresenceConsoleUI(PresenceUseCase presenceUseCase, UseCaseGeneratePresence useCaseGeneratePresence)
        {
            _presenceUseCase = presenceUseCase;
            _useCaseGeneratePresence = useCaseGeneratePresence;
        }

        public void GetPresenceByGroup(int groupId)
        {
            StringBuilder presenceOutput = new StringBuilder();
            var presence = _presenceUseCase.GetPresenceByGroup(groupId);
            foreach (var p in presence)
            {
                presenceOutput.AppendLine($"{p.LessonNumber}\t{p.UserGuid}\t{p.Date}");
            }
            Console.WriteLine(presenceOutput);
        }

        public void GetPresenceByGroupAndDAte(int groupId, DateOnly date)
        {
            StringBuilder presenceOutput = new StringBuilder();
            var presence = _presenceUseCase.GetPresenceByGroupAndDate(groupId, date);
            foreach (var p in presence)
            {
                presenceOutput.AppendLine($"{p.LessonNumber}\t{p.UserGuid}\t{p.Date}");
            }
            Console.WriteLine(presenceOutput);
        }

        public void UnCheckAttendence(int firstClass, int lastClass, DateOnly date, Guid userGuid)
        {
            var result = _presenceUseCase.UnCheckAttendance(firstClass, lastClass, date, userGuid);
            Console.WriteLine(result ? "Посещаемость успешно обновлена" : "Ошибка при обновлении посещаемости");
        }

        public void AddPresence(int firstClass, int lastClass, int groupId, DateOnly date)
        {
            try
            {
                _useCaseGeneratePresence.AddPrecence(firstClass, lastClass, groupId, date);
                Console.WriteLine("Посещаемость успешно добавлена");
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Ошибка при добавлении посещаемости: {ex.Message}");
            }
        }
         public void GetGroupAttendanceStats(int groupId)
        {
            StringBuilder statsOutput = new StringBuilder();
            var groupStats = _presenceUseCase.GetGroupStats(groupId);
            
            statsOutput.AppendLine($"Информация о группе {groupStats.GroupName}:");
            statsOutput.AppendLine($"Количество студентов: {groupStats.StudentsCount}");
            statsOutput.AppendLine($"Количество проведенных занятий: {groupStats.TotalLessons}");
            statsOutput.AppendLine($"Общий процент посещаемости: {groupStats.TotalAttendancePercent:F1}%");
            statsOutput.AppendLine("\nСтатистика по студентам:");
            statsOutput.AppendLine("ФИО\tПосещено\tПропущено\tПроцент посещаемости");
            
            foreach(var student in groupStats.StudentStats)
            {
                statsOutput.AppendLine(
                    $"{student.StudentName}\t{student.AttendedLessons}\t" +
                    $"{student.MissedLessons}\t{student.AttendancePercent:F1}%"
                );
            }
            
            Console.WriteLine(statsOutput.ToString());
        }
    }
       
}
